import java.sql.*;
import java.util.*;

/**
 * A program to test JDCBC connections between Java and Postgres. It provides error messages
 * focused on each statge of the connect and query progress with the aim of helping debug connection
 * issues such as getting the username and password or the database URL correct. 
 */

public class PostgresJDBCTest
{
  
  /**
   * Send a simple query across the connection to print the contents of
   * tableName
   */
  private static void testQuery(Connection conn, String tableName)
  {
    try 
    {
      Statement st = conn.createStatement();
      ResultSet rs = st.executeQuery("SELECT * FROM " + tableName);
      while ( rs.next() )
      {
	  System.out.println(rs.toString());
      }
      rs.close();
      st.close();
    }
    catch (SQLException se) {
      System.err.println("Threw a SQLException while running test query.");
      System.err.println(se.getMessage());
    }
  }

  /**
   * Return a good connection to the database or throw an exception
   * detailing the problem in establshing the connection.
   */
    private static Connection connectToDatabaseOrDie(String url, String userName, String password) {
    Connection conn = null;
    try
    {
      Class.forName("org.postgresql.Driver");
      conn = DriverManager.getConnection(url,userName, password);
    }
    catch (ClassNotFoundException e)
    {
      e.printStackTrace();
      System.exit(1);
    }
    catch (SQLException e)
    {
      e.printStackTrace();
      System.exit(2);
    }
    return conn;
  }

 public static void main(String[] args)
  {
   if (args.length == 4) {
       System.out.println("Attempting to connect to " + args[0] + " as user " + args[1] + " with password " + args[2]);
    Connection conn = connectToDatabaseOrDie( args[0], args[1], args[2]);
    System.out.println("Connection established. Attempting to print contents of table " + args[3]);
    testQuery(conn, args[3]);

    } else {
      System.out.println("Wrong number of arguments " +  args.length + " when I expected 4");
      System.out.println("Usage PostgresJDBCTest <url> <username> <password> <table>");
      System.out.println("e.g. PostgresJDBCTest jdbc:postgresql://localhost:5432/dbasename user1 foo artifact");
    }

  }
}