within AdaptP.Electrical.Basic;
model CircuitBreaker "Commandable Circuit Breaker"
  import AdaptP;
  extends Interfaces.OnePort;
  parameter Boolean command = true;
  Boolean command_i;
  parameter SI.Resistance Ron(final min=0) =   1.E-4 "Closed switch resistance";
  parameter SI.Conductance Goff(final min=0) = 1.E-4;
  parameter SI.Current maxCurrent = 70;

  discrete Boolean isTripped(start = false);
  AdaptP.Interfaces.PositionPort posPort 
    annotation (Placement(transformation(extent={{-10,80},{10,100}})));
  //FM=0 Nominal
  //FM=1 Tripped
  //FM=2 FailedOpen
  //FM=3 StuckClosed
  parameter Integer FM(max=3) = 0;
protected
  Real s(final unit="1") "Auxiliary variable";
  constant SI.Voltage unitVoltage= 1 annotation(HideResult=true);
  constant SI.Current unitCurrent= 1 annotation(HideResult=true);
equation
 command_i = if (pre(isTripped)) then false else 
             if (FM==0) then command else 
             if (FM==1 or FM==2) then false else 
             if (FM==3) then true else 
             command;
  posPort.pos = command;
  //circuit breaker is open command = false
  //circuit breaker is closed command = true
  //i = if (command_i) then v/Ron else 0;
  v = (s*unitCurrent)*(if command_i then Ron else 1);
  i = (s*unitVoltage)*(if command_i then 1 else Goff);
  when (abs(i)>=maxCurrent) then
    isTripped = true;
  end when;
  annotation (Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,
            -100},{100,100}}), graphics={Bitmap(extent={{-100,106},{102,-92}},
            fileName="../../../Icons/CircuitBreaker.bmp"), Text(
          extent={{-142,-77},{158,-117}},
          textString="%name",
          lineColor={0,0,255})}));
end CircuitBreaker;
