within AdaptP.Electrical.Basic;
model LightBulb
  import AdaptP;
  extends Interfaces.OnePort;
  AdaptP.Interfaces.HeatPort heatPort 
    annotation (Placement(transformation(extent={{-10,80},{10,100}})));

  SI.HeatFlowRate q;
  SI.Temperature t(start=294);
  SI.Temperature tenv= 294 "The environment temperature";
  parameter SI.Power pNom = 25;
  SI.Resistance rNom;

  parameter Real heatLightRatio = 0.9
    "Ratio of power that is converted to heat";
  parameter Real heatTransferRatio = 0.6291
    "The heat transfer ratio from the bulb to the enavironment";
  parameter Real heatCapacity = 84.21;

  SI.Power pAct;
  SI.Power heatPower;
  SI.Power envrPower;
equation
  q = heatPort.Q_flow;
  t = heatPort.T;
  //t = 10;

  rNom = (v*v)/pNom;
  v = rNom * i;

  pAct = p.v * p.i;
  heatPower = heatLightRatio * pAct;
  envrPower = heatTransferRatio*(t-tenv);
  der(t)=(heatPower-envrPower)/heatCapacity;

  annotation (Icon(graphics={Bitmap(extent={{-76,82},{76,-86}}, fileName=
              "modelica://AdaptP/../Icons/LightBulb.png"),
          Text(
          extent={{-72,105},{228,65}},
          textString="%name",
          lineColor={0,0,255})}));
end LightBulb;
