within DarpaRLC.Components;
model ResistorH
  extends Modelica.Electrical.Analog.Interfaces.OnePort;
  Modelica.Thermal.HeatTransfer.Interfaces.HeatPort_a heatPort 
    annotation (Placement(transformation(extent={{-10,86},{10,106}})));
  Modelica.SIunits.Power powerDissipation;
  parameter Modelica.SIunits.Temperature Tref=300.15;
  parameter Modelica.SIunits.Resistance R=2;

  Modelica.SIunits.Temp_K TK;
  Modelica.SIunits.Temp_C TC;
  Modelica.SIunits.Temp_K TheatPort;

  Real sigma = 5.670400e-8;
equation
  v = R*i;
  powerDissipation = v*i;

  //the Stafan Boltzman equation
  powerDissipation = sigma * (TK^4 - Tref^4);
  TC = Modelica.SIunits.Conversions.to_degC(abs(TK));
  TheatPort = abs(TK);

  //heat port
  heatPort.T = TheatPort;
  heatPort.Q_flow = powerDissipation;
  annotation (Icon(graphics={
          Rectangle(extent={{-68,30},{72,-30}}, lineColor={0,0,255}),
          Line(points={{-94,0},{-68,0}}, color={0,0,255}),
          Line(points={{72,0},{98,0}}, color={0,0,255}),
          Text(
            extent={{-140,-40},{146,-72}},
            lineColor={0,0,0},
            textString="R=%R"),
          Line(
            visible=useHeatPort,
            points={{10,-90},{10,-20}},
            color={127,0,0},
            smooth=Smooth.None,
            pattern=LinePattern.Dot),
          Text(
            extent={{-148,77},{152,37}},
            textString="%name",
            lineColor={0,0,255})}));
end ResistorH;
