within RampMETA.Control.Continuous;
block Add "Output the sum of the two inputs"
  extends Modelica.Blocks.Interfaces.SI2SO;
  parameter Real k1=+1 "Gain of upper input";
  parameter Real k2=+1 "Gain of lower input";

equation
  y = k1*u1 + k2*u2;
  annotation (
    Documentation(info="
<HTML>
<p>
This blocks computes output <b>y</b> as <i>sum</i> of the
two input signals <b>u1</b> and <b>u2</b>:
</p>
<pre>
    <b>y</b> = k1*<b>u1</b> + k2*<b>u2</b>;
</pre>
<p>
Example:
</p>
<pre>
     parameter:   k1= +2, k2= -3

  results in the following equations:

     y = 2 * u1 - 3 * u2
</pre>

</HTML>
"), Icon(coordinateSystem(
    preserveAspectRatio=true,
    extent={{-100,-100},{100,100}},
    grid={2,2}), graphics={
    Text(
      extent={{-98,-52},{7,-92}},
      lineColor={0,0,0},
      textString="%k2"),
    Text(
      extent={{-100,90},{5,50}},
      lineColor={0,0,0},
      textString="%k1"),
    Text(
      extent={{-150,150},{150,110}},
      textString="%name",
      lineColor={0,0,255}),
    Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
    Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
    Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
    Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
    Rectangle(
      extent={{-100,-100},{100,100}},
      lineColor={0,0,127},
      fillColor={255,255,255},
      fillPattern=FillPattern.Solid),
    Line(points={{50,0},{100,0}}, color={0,0,255}),
    Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
    Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
    Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
    Line(points={{50,0},{100,0}}, color={0,0,127}),
    Text(
      extent={{-38,34},{38,-34}},
      lineColor={0,0,0},
      textString="+"),
    Text(
      extent={{-100,52},{5,92}},
      lineColor={0,0,0},
      textString="%k1"),
    Text(
      extent={{-100,-52},{5,-92}},
      lineColor={0,0,0},
      textString="%k2")}),
    Diagram(coordinateSystem(
    preserveAspectRatio=true,
    extent={{-100,-100},{100,100}},
    grid={2,2}), graphics={
    Rectangle(
      extent={{-100,-100},{100,100}},
      lineColor={0,0,255},
      fillColor={255,255,255},
      fillPattern=FillPattern.Solid),
    Text(
      extent={{-98,-52},{7,-92}},
      lineColor={0,0,0},
      textString="%k2"),
    Text(
      extent={{-100,90},{5,50}},
      lineColor={0,0,0},
      textString="%k1"),
    Line(points={{-100,60},{-40,60},{-30,40}}, color={0,0,255}),
    Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,255}),
    Line(points={{-100,-60},{-40,-60},{-30,-40}}, color={0,0,255}),
    Line(points={{-15,-25.99},{15,25.99}}, color={0,0,0}),
    Rectangle(
      extent={{-100,-100},{100,100}},
      lineColor={0,0,127},
      fillColor={255,255,255},
      fillPattern=FillPattern.Solid),
    Line(points={{50,0},{100,0}}, color={0,0,255}),
    Line(points={{-100,60},{-74,24},{-44,24}}, color={0,0,127}),
    Line(points={{-100,-60},{-74,-28},{-42,-28}}, color={0,0,127}),
    Ellipse(extent={{-50,50},{50,-50}}, lineColor={0,0,127}),
    Line(points={{50,0},{100,0}}, color={0,0,127}),
    Text(
      extent={{-38,34},{38,-34}},
      lineColor={0,0,0},
      textString="+"),
    Text(
      extent={{-100,52},{5,92}},
      lineColor={0,0,0},
      textString="k1"),
    Text(
      extent={{-100,-52},{5,-92}},
      lineColor={0,0,0},
      textString="k2")}));
end Add;
