within RampMETA.Control.Continuous;
block Sum "Output the sum of the elements of the input vector"
  extends Modelica.Blocks.Interfaces.MISO;
  parameter Real k[nin]=ones(nin) "Optional: sum coefficients";
equation
  y = k*u;
  annotation (defaultComponentName="sum1",
    Documentation(info="
<HTML>
<p>
This blocks computes output <b>y</b> as
<i>sum</i> of the elements of the input signal vector
<b>u</b>:
</p>
<pre>
    <b>y</b> = <b>u</b>[1] + <b>u</b>[2] + ...;
</pre>
<p>
Example:
</p>
<pre>
     parameter:   nin = 3;

  results in the following equations:

     y = u[1] + u[2] + u[3];
</pre>

</HTML>
"), Icon(coordinateSystem(
    preserveAspectRatio=true,
    extent={{-100,-100},{100,100}},
    grid={2,2}), graphics={Line(
      points={{26,42},{-34,42},{6,2},{-34,-38},{26,-38}},
      color={0,0,0},
      thickness=0.25), Text(
      extent={{-150,150},{150,110}},
      textString="%name",
      lineColor={0,0,255})}),
    Diagram(coordinateSystem(
    preserveAspectRatio=true,
    extent={{-100,-100},{100,100}},
    grid={2,2}), graphics={Rectangle(
      extent={{-100,-100},{100,100}},
      lineColor={0,0,255},
      fillColor={255,255,255},
      fillPattern=FillPattern.Solid), Line(
      points={{26,42},{-34,42},{6,2},{-34,-38},{26,-38}},
      color={0,0,0},
      thickness=0.25)}));
end Sum;
