within RampMETA.Control;
model control_candidate_2
  "This is a position controller tracking a reference step command. "

  Modelica.Blocks.Interfaces.RealInput position_ref
    "Connector of set point input signal" 
    annotation (Placement(transformation(extent={{-120,52},{-94,78}},
        rotation=0)));
  Modelica.Blocks.Interfaces.RealInput measured_position
    "Connector of measurement input signal" 
    annotation (Placement(transformation(
      origin={0,-104},
      extent={{20,-20},{-20,20}},
      rotation=270)));
  Modelica.Blocks.Interfaces.RealOutput y "Connector of actuator output signal"
    annotation (Placement(transformation(extent={{98,4},{116,22}},
        rotation=0)));
  Modelica.Blocks.Math.Add addP(k2=-1, k1=1) 
    annotation (Placement(transformation(extent={{-48,18},{-38,28}}, rotation=
           0)));
  Modelica.Blocks.Math.Gain P(k=kp_position) 
    annotation (Placement(transformation(extent={{-24,18},{-14,28}},
                      rotation=0)));
  Modelica.Blocks.Continuous.Derivative D(y_start=0, k=kd_position) 
    annotation (Placement(transformation(extent={{-24,0},{-14,10}},
          rotation=0)));
  Modelica.Blocks.Math.Gain gainPD(k=k_position) 
    annotation (Placement(transformation(extent={{14,8},{24,18}},
                               rotation=0)));
  Modelica.Blocks.Math.Add addD( k2=-1) 
    annotation (Placement(transformation(extent={{-48,0},{-38,10}})));
  parameter Real kp_position=1000 "Gain value multiplied with input signal";
  parameter Real k_position=1000 "Gain value multiplied with input signal";
  parameter Real kd_position=120 "Gains";
  Modelica.Blocks.Math.Add addPD(      k1=1, k2=1) 
    annotation (Placement(transformation(extent={{-6,8},{4,18}},     rotation=
           0)));
equation
  connect(position_ref,addP. u1) 
                        annotation (Line(points={{-107,65},{-82,65},{-82,26},{
          -49,26}}, color={0,0,127}));
  connect(addP.y,P. u) annotation (Line(points={{-37.5,23},{-25,23}},
                                                                    color={0,
          0,127}));
  connect(position_ref,addD. u1) annotation (Line(
      points={{-107,65},{-82,65},{-82,8},{-49,8}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(D.u,addD. y) annotation (Line(
      points={{-25,5},{-37.5,5}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(gainPD.y, y) annotation (Line(
      points={{24.5,13},{107,13}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(addPD.u1, P.y) annotation (Line(
      points={{-7,16},{-10,16},{-10,23},{-13.5,23}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(addPD.u2, D.y) annotation (Line(
      points={{-7,10},{-10,10},{-10,5},{-13.5,5}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(addPD.y, gainPD.u) annotation (Line(
      points={{4.5,13},{13,13}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(measured_position, addD.u2) annotation (Line(
      points={{0,-104},{-74,-104},{-74,2},{-49,2}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(measured_position, addP.u2) annotation (Line(
      points={{0,-104},{-74,-104},{-74,20},{-49,20}},
      color={0,0,127},
      smooth=Smooth.None));
  annotation (Diagram(graphics={
      Text(
        extent={{-82,36},{-122,26}},
        textString="(setpoint)",
        lineColor={0,0,255}),
      Text(
        extent={{86,36},{126,26}},
        textString="(actuator)",
        lineColor={0,0,255}),
      Text(
        extent={{-27,-88},{48,-78}},
        textString=" (measurement)",
        lineColor={0,0,255})}));
end control_candidate_2;
