within RampMETA.Control;
block control_candidate_A03 "This is a simple PID controller. "

  Sources.RealInput velocity_ref "Connector of setpoint input signal" 
    annotation (Placement(transformation(extent={{-140,-26},{-100,14}},
        rotation=0), iconTransformation(extent={{-120,-10},{-100,10}})));
  Modelica.Blocks.Interfaces.RealInput measured_velocity
    "Connector of measurement input signal" 
    annotation (Placement(transformation(
      origin={4,-120},
      extent={{20,-20},{-20,20}},
      rotation=270), iconTransformation(
        extent={{10,-10},{-10,10}},
        rotation=270,
        origin={0,-110})));
  Continuous.Add addP(          k2=-1, k1=1) 
    annotation (Placement(transformation(extent={{-62,8},{-52,18}},  rotation=
           0)));
  Modelica.Blocks.Math.Gain P(k=kp_velocity) 
    annotation (Placement(transformation(extent={{-32,20},{-20,
            32}},     rotation=0)));
  Modelica.Blocks.Continuous.Integrator I(y_start=0, k=ki_velocity) 
    annotation (Placement(transformation(extent={{-30,-20},{-18,-8}},
          rotation=0)));
  Modelica.Blocks.Math.Gain gainPID(k=k_velocity) 
    annotation (Placement(transformation(extent={{24,4},{36,16}},
                               rotation=0)));
  Modelica.Blocks.Math.Add3 addPID 
    annotation (Placement(transformation(
          extent={{4,2},{14,12}},   rotation=0)));
 Continuous.Add addSat(          k1=+1, k2=-1) 
    annotation (Placement(transformation(
        origin={45,-25},
        extent={{-5,-5},{5,5}},
        rotation=270)));
  Modelica.Blocks.Math.Gain gainTrack(k=1/(k_velocity*0.9)) 
    annotation (Placement(transformation(extent={{-40,-40},{-52,-28}},
                                                                     rotation=
           0)));
  Modelica.Blocks.Nonlinear.Limiter limiter(uMax=yMax, uMin=yMin,
    limitsAtInit=false) 
    annotation (Placement(transformation(extent={{48,6},{58,16}},   rotation=
            0)));
  Modelica.Blocks.Sources.Constant feedthrough_bias(k=0)
    "Incase we need to apply some constant bias torque" 
    annotation (Placement(transformation(extent={{-32,10},{-22,0}}, rotation=
            0)));
  parameter Real kp_velocity=100 "Gain value multiplied with input signal";
  parameter Real ki_velocity=500 "Integrator gain";
  parameter Real k_velocity=1400 "Gain value multiplied with input signal";
  parameter Real yMax=100000 "Upper limits of input signals";
  parameter Real yMin=-yMax "Lower limits of input signals";
  Modelica.Blocks.Math.Add3 addI(k2=-1) 
    annotation (Placement(transformation(
          extent={{-52,-20},{-42,-10}},
                                    rotation=0)));
  Sources.RealOutput y 
    annotation (Placement(transformation(extent={{100,-10},{120,10}}),
        iconTransformation(extent={{100,-10},{120,10}})));
equation
  connect(velocity_ref, addP.u1) 
                        annotation (Line(points={{-120,-6},{-92,-6},{-92,16},{
          -63,16}}, color={0,0,127}));
  connect(addP.y,P. u) annotation (Line(points={{-51.5,13},{-44,13},{-44,26},{-33.2,
          26}},                                                     color={0,
          0,127}));
  connect(P.y,addPID. u1) annotation (Line(points={{-19.4,26},{-6,26},{-6,11},{3,
          11}},    color={0,0,127}));
  connect(I.y,addPID. u3) annotation (Line(points={{-17.4,-14},{-6,-14},{-6,3},
          {3,3}},       color={0,0,127}));
  connect(addPID.y,gainPID. u) 
    annotation (Line(points={{14.5,7},{16,7},{18,7},{18,10},{22.8,10}},
                                             color={0,0,127}));
  connect(gainPID.y,limiter. u) 
    annotation (Line(points={{36.6,10},{42,10},{42,11},{47,11}},
                                             color={0,0,127}));
  connect(limiter.y,addSat. u1) annotation (Line(points={{58.5,11},{62,11},{62,
          4},{62,-19},{48,-19}},   color={0,0,127}));
  connect(addSat.y,gainTrack. u) annotation (Line(points={{45,-30.5},{45,-34},{
          -38.8,-34}},
                    color={0,0,127}));
  connect(measured_velocity, addP.u2) 
                        annotation (Line(
      points={{4,-120},{4,-56},{-88,-56},{-88,10},{-63,10}},
      color={0,0,127},
      thickness=0.5));
  connect(feedthrough_bias.y, addPID.u2) annotation (Line(
      points={{-21.5,5},{-9.65,5},{-9.65,7},{3,7}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(addSat.u2, gainPID.y) annotation (Line(
      points={{42,-19},{42,10},{36.6,10}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(addI.y, I.u) annotation (Line(
      points={{-41.5,-15},{-35.75,-15},{-35.75,-14},{-31.2,-14}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(velocity_ref, addI.u1) annotation (Line(
      points={{-120,-6},{-88,-6},{-88,-11},{-53,-11}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(measured_velocity, addI.u2) annotation (Line(
      points={{4,-120},{4,-78},{-82,-78},{-82,-14},{-53,-14},{-53,-15}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(gainTrack.y, addI.u3) annotation (Line(
      points={{-52.6,-34},{-72,-34},{-72,-19},{-53,-19}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(limiter.y, y) annotation (Line(
      points={{58.5,11},{72.25,11},{72.25,0},{110,0}},
      color={0,0,127},
      smooth=Smooth.None));
  annotation (Diagram(graphics={
      Text(
        extent={{-92,26},{-132,16}},
        textString="(setpoint)",
        lineColor={0,0,255}),
      Text(
        extent={{76,26},{116,16}},
        textString="(actuator)",
        lineColor={0,0,255}),
      Text(
        extent={{-37,-98},{38,-88}},
        textString=" (measurement)",
        lineColor={0,0,255})}), Icon(graphics={Text(
          extent={{-74,20},{62,-22}},
          lineColor={0,0,255},
          textString="Control"), Rectangle(extent={{-100,100},{100,-100}},
            lineColor={0,0,255})}));
end control_candidate_A03;
