within RampMETA.Electrical.Basic;
model Inverter "DC to AC Inverter"
  // Characteristics of the Xantrex PROsine 1000Watt Inverter
  // Output power 1000W
  // Surge rating 1500W
  // Ouput current (peak) 25A
  // Outpur voltage (at no load) 120Vac +/-3%
  // Output voltage (over full load and battery voltage range) 120 Vac RMS -10%/+4%
  // Output frequency 60 +/-0.05 (Crystall controlled)
  // Output waveform: True sine wave (<3% THD)
  // Peak efficiency (12V/24V) 89% / 90%
  // No load power draw (search mode)  <1.5W
  // No load power draw (idle mode)  < 22W
  // Input voltage range (12V/24V)  10-16Vdc/20-32 Vdc
  // Transfer relay rating (hardwire/transfer relay models)

  parameter Real inv_efficiency = 0.9; //invertor efficency in percentage
  parameter Modelica.SIunits.Voltage outputvoltage=120;
  Modelica.SIunits.Voltage invvoltage;
  RampMETA.Electrical.Interfaces.Pin pDC 
    annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
  RampMETA.Electrical.Interfaces.Pin pAC 
    annotation (Placement(transformation(extent={{80,-10},{100,10}})));

  //NominalOn, NominalOff, FailedOff
  //FM=0 NominalOn
  //FM=1 NominalOff
  //FM=2 FailedOff
  parameter Integer FM(max=2) = 0;
equation
  invvoltage = if (FM==0) then outputvoltage else 
               if (FM==1) then 0 else 
               if (FM==2) then 0 else 
               outputvoltage;
  //power balance equation
  (pDC.i*pDC.v)* inv_efficiency = pAC.i*pAC.v;
   pAC.v = invvoltage;
  annotation (Icon(coordinateSystem(preserveAspectRatio=true,  extent={{-100,
            -100},{100,100}}), graphics={
        Text(
          extent={{-154,111},{146,71}},
          textString="%name",
          lineColor={0,0,255}), Bitmap(extent={{-72,76},{74,-78}}, fileName=
              "modelica://RampMETA/Icons/inverter.jpg")}),
                                  Diagram(graphics));
end Inverter;
