within RampMETA.Electrical.Basic;
model InverterXantrexFreedom "DC to AC Inverter"
  // Characteristics of the Xantrex PROsine 1000Watt Inverter
  // Output power 1000W
  // Surge rating 1500W
  // Ouput current (peak) 25A
  // Outpur voltage (at no load) 120Vac +/-3%
  // Output voltage (over full load and battery voltage range) 120 Vac RMS -10%/+4%
  // Output frequency 60 +/-0.05 (Crystall controlled)
  // Output waveform: True sine wave (<3% THD)
  // Peak efficiency (12V/24V) 89% / 90%
  // No load power draw (search mode)  <1.5W
  // No load power draw (idle mode)  < 22W
  // Input voltage range (12V/24V)  10-16Vdc/20-32 Vdc
  // Transfer relay rating (hardwire/transfer relay models)

  parameter Real inv_efficiency = 0.85; //invertor efficency in percentage
  parameter Modelica.SIunits.Voltage outputvoltage=115;
  RampMETA.Electrical.Interfaces.Pin pDC 
    annotation (Placement(transformation(extent={{-100,-10},{-80,10}})));
  RampMETA.Electrical.Interfaces.Pin pAC 
    annotation (Placement(transformation(extent={{80,-10},{100,10}})));
equation
  //power balance equation
  (pDC.i*pDC.v)* inv_efficiency = pAC.i*pAC.v;
   pAC.v = outputvoltage;
  annotation (Icon(coordinateSystem(preserveAspectRatio=true,  extent={{-100,
            -100},{100,100}}), graphics={
        Text(
          extent={{-154,111},{146,71}},
          textString="%name",
          lineColor={0,0,255}), Bitmap(extent={{-80,84},{78,-86}}, fileName=
              "modelica://RampMETA/Icons/inverter.jpg"),
        Text(
          extent={{-72,-100},{76,-64}},
          lineColor={0,0,255},
          textString="Freedom")}),Diagram(graphics));
end InverterXantrexFreedom;
