within RampMETA.Electrical.Basic;
model LargeFan "Large Fan"
  extends RampMETA.Electrical.Interfaces.OnePort;

  parameter Modelica.SIunits.Resistance rNom=141.8317;
  parameter Modelica.SIunits.Resistance rOverspeed=107.9439;
  parameter Modelica.SIunits.Resistance rUnderspeed=168.0570;

  Modelica.SIunits.Resistance rAct;
                       // internal resistance
  Modelica.SIunits.Power pAct;
                       // actual power consumption
  Real rpm;

  parameter Real a = -0.0150;
  parameter Real b = 9.1222;
  parameter Real c = 125.4976;
  //Nominal, OverSpeed, UnderSpeed, FailedOff
  //FM=0 Nominal
  //FM=1 OverSpeed
  //FM=2 UnderSpeed
  //FM=3 FailedOff
  parameter Integer FM(max=3) = 0;

  RampMETA.Electrical.Interfaces.SpeedPort speedPort 
    annotation (Placement(transformation(extent={{-10,80},{10,100}})));
equation
  rAct = if (FM == 0) then rNom else 
         if (FM == 1) then rOverspeed else 
         if (FM == 2) then rUnderspeed else 
         if (FM == 3) then 0.0001 else 
         rNom;

  v = rAct*i;
  //calculate the power consumption in the fan
  pAct = p.i*p.v;
  // quadratic relantionship between pAct and rpm
  rpm = pAct*pAct*a + pAct*b + c;

  //send out the rpm to the sensor
  speedPort.s = rpm;

  annotation (Icon(coordinateSystem(preserveAspectRatio=true,  extent={{-100,
            -100},{100,100}}), graphics={
        Text(
          extent={{-144,-65},{156,-105}},
          textString="%name",
          lineColor={0,0,255}), Bitmap(extent={{-68,74},{68,-72}}, fileName=
              "modelica://RampMETA/Icons/Fan.JPG")}),
                                  Diagram(graphics));
end LargeFan;
