within RampMETA.Electrical.Basic;
model LightBulb
  extends RampMETA.Electrical.Interfaces.OnePort;
  RampMETA.Electrical.Interfaces.HeatPort heatPort 
    annotation (Placement(transformation(extent={{-10,80},{10,100}})));

  Modelica.SIunits.HeatFlowRate q;
  Modelica.SIunits.Temperature t(start=294);
  Modelica.SIunits.Temperature tenv=294 "The environment temperature";
  parameter Modelica.SIunits.Power pNom=25;
  Modelica.SIunits.Resistance rNom;

  parameter Real heatLightRatio = 0.1
    "Ratio of power that is converted to heat";
  parameter Real heatTransferRatio = 0.6291
    "The heat transfer ratio from the bulb to the enavironment";
  parameter Real heatCapacity = 84.21;

  Modelica.SIunits.Power pAct;
  Modelica.SIunits.Power heatPower;
  Modelica.SIunits.Power envrPower;
equation
  q = heatPort.Q_flow;
  t = heatPort.T;
  //t = 10;

  rNom = 10+(v*v)/pNom;
  v = rNom * i;

  pAct = p.v * p.i;
  heatPower = heatLightRatio * pAct;
  envrPower = heatTransferRatio*(t-tenv);
  der(t)=(heatPower-envrPower)/heatCapacity;

  annotation (Icon(graphics={Bitmap(extent={{-76,82},{76,-86}}, fileName=
              "modelica://RampMETA/Icons/LightBulb.png"),
          Text(
          extent={{-72,105},{228,65}},
          textString="%name",
          lineColor={0,0,255})}));
end LightBulb;
