within RampMETA.Examples;
model RampEX01
  parameter Modelica.SIunits.Angle driveAngle=3.57 "Reference distance to move";
  Control.Sources.KinematicPTP kinematicPTP(startTime=0.5,
    qd_max={1},
    qdd_max={1},
    deltaq={driveAngle}) 
    annotation (Placement(transformation(extent={{-84,32},{-64,52}})));
  Control.Continuous.Integrator integrator(initType=Modelica.Blocks.Types.Init.InitialState) 
    annotation (Placement(transformation(extent={{-48,32},{-28,52}})));
  Control.Continuous.LimPID PI(
    k=100,
    Ti=0.1,
    Td=0.1,
    yMax=12,
    wp=1,
    Ni=0.1,
    controllerType=Modelica.Blocks.Types.SimpleController.PID,
    initType=Modelica.Blocks.Types.InitPID.NoInit,
    limitsAtInit=true) 
    annotation (Placement(transformation(extent={{-16,32},{4,52}})));
  Mechanics.Rotational.Sources.Torque torque 
    annotation (Placement(transformation(extent={{16,32},{36,52}})));
  Mechanics.Rotational.Components.Inertia inertia(
    J=1,
    phi(fixed=true, start=0),
    a(fixed=true)) 
    annotation (Placement(transformation(extent={{44,32},{64,52}})));
  Mechanics.Rotational.Components.SpringDamper springDamper(
    c=1e4,
    d=100,
    phi_rel0=0,
    w_rel(fixed=true)) 
    annotation (Placement(transformation(extent={{76,32},{96,52}})));
  Mechanics.Rotational.Components.Inertia inertia1(J=2) 
    annotation (Placement(transformation(extent={{106,32},{126,52}})));
  Mechanics.Rotational.Sources.ConstantTorque constantTorque(tau_constant=10) 
    annotation (Placement(transformation(extent={{156,32},{136,52}})));
  Mechanics.Rotational.Sensors.SpeedSensor speedSensor 
    annotation (Placement(transformation(extent={{40,-18},{20,2}})));
equation
  connect(kinematicPTP.y[1], integrator.u) annotation (Line(
      points={{-63,42},{-50,42}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(integrator.y, PI.u_s) annotation (Line(
      points={{-27,42},{-18,42}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(PI.y, torque.tau) annotation (Line(
      points={{5,42},{14,42}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(torque.flange, inertia.flange_a) annotation (Line(
      points={{36,42},{44,42}},
      color={0,0,0},
      smooth=Smooth.None));
  connect(inertia.flange_b, springDamper.flange_a) annotation (Line(
      points={{64,42},{76,42}},
      color={0,0,0},
      smooth=Smooth.None));
  connect(springDamper.flange_b, inertia1.flange_a) annotation (Line(
      points={{96,42},{106,42}},
      color={0,0,0},
      smooth=Smooth.None));
  connect(inertia1.flange_b, constantTorque.flange) annotation (Line(
      points={{126,42},{136,42}},
      color={0,0,0},
      smooth=Smooth.None));
  connect(speedSensor.flange, inertia.flange_b) annotation (Line(
      points={{40,-8},{72,-8},{72,42},{64,42}},
      color={0,0,0},
      smooth=Smooth.None));
  connect(speedSensor.w, PI.u_m) annotation (Line(
      points={{19,-8},{-6,-8},{-6,30}},
      color={0,0,127},
      smooth=Smooth.None));
  annotation (Diagram(graphics));
end RampEX01;
