within RampMETA.Mechanics.Rotational.Components;
model Damper "Linear 1D rotational damper"
  extends
    Modelica.Mechanics.Rotational.Interfaces.PartialCompliantWithRelativeStates;
  parameter Modelica.SIunits.RotationalDampingConstant d(final min=0, start=0)
    "Damping constant";

equation
  tau = d*w_rel;
  annotation (
    Documentation(info="<html>
<p>
<b>Linear, velocity dependent damper</b> element. It can be either connected
between an inertia or gear and the housing (component Fixed), or
between two inertia/gear elements.
</p>

</HTML>
"), Icon(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics={
        Line(points={{-90,0},{-60,0}}, color={0,0,0}),
        Line(points={{-60,-30},{-60,30}}, color={0,0,0}),
        Line(points={{-60,-30},{60,-30}}, color={0,0,0}),
        Line(points={{-60,30},{60,30}}, color={0,0,0}),
        Rectangle(
          extent={{-60,30},{30,-30}},
          lineColor={0,0,0},
          fillColor={192,192,192},
          fillPattern=FillPattern.Solid),
        Line(points={{30,0},{90,0}}, color={0,0,0}),
        Text(
          extent={{-150,80},{150,40}},
          textString="%name",
          lineColor={0,0,255}),
        Text(
          extent={{-150,-50},{150,-90}},
          lineColor={0,0,0},
          textString="d=%d")}),
    Diagram(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics={
        Line(points={{-96,0},{-60,0}}, color={0,0,0}),
        Line(points={{-60,-30},{-60,30}}, color={0,0,0}),
        Line(points={{-60,-30},{60,-30}}, color={0,0,0}),
        Line(points={{-60,30},{60,30}}, color={0,0,0}),
        Rectangle(
          extent={{-60,30},{30,-30}},
          lineColor={0,0,0},
          fillColor={192,192,192},
          fillPattern=FillPattern.Solid),
        Line(points={{30,0},{96,0}}, color={0,0,0}),
        Line(points={{-68,0},{-68,65}}, color={128,128,128}),
        Text(
          extent={{-22,62},{18,87}},
          lineColor={0,0,255},
          textString="phi_rel"),
        Line(points={{-68,60},{72,60}}, color={128,128,128}),
        Line(points={{72,0},{72,65}}, color={128,128,128}),
        Polygon(
          points={{62,63},{72,60},{62,57},{62,63}},
          lineColor={128,128,128},
          fillColor={128,128,128},
          fillPattern=FillPattern.Solid)}));
end Damper;
