within RampMETA.Mechanics.Rotational.Sensors;
model TorqueSensor
  "Ideal sensor to measure the torque between two flanges (= flange_a.tau)"

  extends Modelica.Mechanics.Rotational.Interfaces.PartialRelativeSensor;
  Modelica.Blocks.Interfaces.RealOutput tau
    "Torque in flange flange_a and flange_b (tau = flange_a.tau = -flange_b.tau)"
annotation (Placement(transformation(
        origin={-80,-110},
        extent={{10,-10},{-10,10}},
        rotation=90)));

equation
  flange_a.phi = flange_b.phi;
  flange_a.tau = tau;
  annotation (
    Documentation(info="<html>
<p>
Measures the <b>cut-torque between two flanges</b> in an ideal way
and provides the result as output signal <b>tau</b>
(to be further processed with blocks of the Modelica.Blocks library).
</p>

</HTML>
"), Icon(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics={Text(
          extent={{-50,-80},{50,-120}},
          lineColor={0,0,0},
          textString="tau"), Line(points={{-80,-100},{-80,0}}, color={0,0,
              127})}),
    Diagram(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics));
end TorqueSensor;
