within RampMETA.Mechanics.Rotational.Sources;
model Fixed "Flange fixed in housing at a given angle"
  parameter Modelica.SIunits.Angle phi0=0 "Fixed offset angle of housing";

  Modelica.Mechanics.Rotational.Interfaces.Flange_b flange
    "(right) flange fixed in housing" 
    annotation (Placement(transformation(extent={{10,-10},{-10,10}}, rotation=
           0)));

equation
  flange.phi = phi0;
  annotation (
    Icon(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={2,2}), graphics={
        Text(
          extent={{-150,-90},{150,-130}},
          lineColor={0,0,255},
          textString="%name"),
        Line(points={{-80,-40},{80,-40}}, color={0,0,0}),
        Line(points={{80,-40},{40,-80}}, color={0,0,0}),
        Line(points={{40,-40},{0,-80}}, color={0,0,0}),
        Line(points={{0,-40},{-40,-80}}, color={0,0,0}),
        Line(points={{-40,-40},{-80,-80}}, color={0,0,0}),
        Line(points={{0,-40},{0,-10}}, color={0,0,0})}),
    Documentation(info="<html>
<p>
The <b>flange</b> of a 1D rotational mechanical system is <b>fixed</b>
at an angle phi0 in the <b>housing</b>. May be used:
</p>
<ul>
<li> to connect a compliant element, such as a spring or a damper,
     between an inertia or gearbox component and the housing.
<li> to fix a rigid element, such as an inertia, with a specific
     angle to the housing.
</ul>

</HTML>
"), Diagram(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={2,2}), graphics={
        Line(points={{-80,-40},{80,-40}}, color={0,0,0}),
        Line(points={{80,-40},{40,-80}}, color={0,0,0}),
        Line(points={{40,-40},{0,-80}}, color={0,0,0}),
        Line(points={{0,-40},{-40,-80}}, color={0,0,0}),
        Line(points={{-40,-40},{-80,-80}}, color={0,0,0}),
        Line(points={{0,-40},{0,-4}}, color={0,0,0})}));
end Fixed;
