within RampMETA.Mechanics.Rotational.Sources;
model Torque "Input signal acting as external torque on a flange"
  extends
    Modelica.Mechanics.Rotational.Interfaces.PartialElementaryOneFlangeAndSupport2;
  Modelica.Blocks.Interfaces.RealInput tau
    "Accelerating torque acting at flange (= -flange.tau)" 
    annotation (Placement(transformation(extent={{-140,-20},{-100,20}},
          rotation=0)));

equation
  flange.tau = -tau;
  annotation (
    Documentation(info="<HTML>
<p>
The input signal <b>tau</b> defines an external
torque in [Nm] which acts (with negative sign) at
a flange connector, i.e., the component connected to this
flange is driven by torque <b>tau</b>.</p>
<p>
The input signal can be provided from one of the signal generator
blocks of Modelica.Blocks.Sources.
</p>

</HTML>
"), Icon(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics={
        Text(
          extent={{-150,110},{150,70}},
          textString="%name",
          lineColor={0,0,255}),
        Text(
          extent={{-62,-29},{-141,-70}},
          lineColor={0,0,0},
          textString="tau"),
        Line(
          points={{-88,0},{-64,30},{-36,52},{-2,62},{28,56},{48,44},{64,28},
              {76,14},{86,0}},
          color={0,0,0},
          thickness=0.5),
        Polygon(
          points={{86,0},{66,58},{37,27},{86,0}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid),
        Line(points={{-30,-30},{30,-30}}, color={0,0,0}),
        Line(points={{0,-30},{0,-101}}, color={0,0,0}),
        Line(points={{-30,-50},{-10,-30}}, color={0,0,0}),
        Line(points={{-10,-50},{10,-30}}, color={0,0,0}),
        Line(points={{10,-50},{30,-30}}, color={0,0,0}),
        Line(points={{-54,-42},{-38,-28},{-16,-16},{4,-14},{22,-18},{36,-26},
              {48,-36},{56,-46},{64,-58}}, color={0,0,0}),
        Polygon(
          points={{-61,-66},{-44,-42},{-58,-36},{-61,-66}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid)}),
    Diagram(coordinateSystem(
        preserveAspectRatio=true,
        extent={{-100,-100},{100,100}},
        grid={1,1}), graphics={
        Text(
          extent={{14,86},{82,73}},
          lineColor={128,128,128},
          textString="rotation axis"),
        Polygon(
          points={{10,80},{-10,85},{-10,75},{10,80}},
          lineColor={128,128,128},
          fillColor={128,128,128},
          fillPattern=FillPattern.Solid),
        Line(points={{-80,80},{-9,80}}, color={128,128,128}),
        Line(
          points={{-88,0},{-64,30},{-36,52},{-2,62},{28,56},{48,44},{64,28},
              {76,14},{80,10}},
          color={0,0,0},
          thickness=0.5),
        Polygon(
          points={{86,0},{66,58},{38,28},{86,0}},
          lineColor={0,0,0},
          fillColor={0,0,0},
          fillPattern=FillPattern.Solid)}));
end Torque;
